@@ -7,7 +7,6 @@ use inflector::Inflector;
 use std::iter::Chain;
 use std::slice::Iter;
 
-//todo: avoid static mut
 pub(crate) static mut TYPE_CASE: TypeCases = TypeCases::Default;
 
 #[derive(Debug, new)]
@@ -354,8 +353,7 @@ impl TraitTest {
         }
     }
 }
-*//*
-todo!()
+*/
 #[cfg(test)]
 mod tests {
     //use crate::enums::Types;
@@ -424,4 +422,3 @@ mod tests {
         //TODO
     }
 }
-*/
\ No newline at end of file
